// SgeSet.h: Schnittstelle für die Klasse CSgeSet.
//
//////////////////////////////////////////////////////////////////////

#if !defined(AFX_SGESET_H__4FD043A4_5488_11D2_81F1_0000B45BAE88__INCLUDED_)
#define AFX_SGESET_H__4FD043A4_5488_11D2_81F1_0000B45BAE88__INCLUDED_
/*___INFO__MARK_BEGIN__*/
/*************************************************************************
 * 
 *  The Contents of this file are made available subject to the terms of
 *  the Sun Industry Standards Source License Version 1.2
 * 
 *  Sun Microsystems Inc., March, 2001
 * 
 * 
 *  Sun Industry Standards Source License Version 1.2
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.2 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://gridengine.sunsource.net/Gridengine_SISSL_license.html
 * 
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 * 
 *   The Initial Developer of the Original Code is: Sun Microsystems, Inc.
 * 
 *   Copyright: 2001 by Sun Microsystems, Inc.
 * 
 *   All Rights Reserved.
 * 
 ************************************************************************/
/*___INFO__MARK_END__*/

#if _MSC_VER >= 1000
#pragma once
#endif // _MSC_VER >= 1000

#pragma warning(disable:4786)	// Ansonsten werden Warnungen ausgegeben, weil der Compiler
								// Symbole für Debug-Informationen auf 255 Zeichen verkürzt.
								// (set generiert Symbole mit mehr als 255 Zeichen!!!!!)
#include "SgeObj.h"
#include <set>

typedef std::set<int> intset;

class CSgeSet  
{
public:
	CSgeSet();
	virtual ~CSgeSet();

	int  IsLocal();
	int	 *GetModIntVector();
	bool IsAmbiguous() const;
	bool IsAmbiguous(int Fieldname) const;
	void ClearAmbiguous();
	void ClearAmbiguous(int Fieldname);
	void SetAmbiguous(int Fieldname);
	bool IsModified() const;
	bool IsModified(int Fieldname) const;
	void ClearModified();
	void ClearModified(int Fieldname);
	void SetModified(int Fieldname);

private:
	int	   *m_pModIntVector;
	intset m_AmbiguousSet;
	intset m_ModifiedSet;
};

#endif // !defined(AFX_SGESET_H__4FD043A4_5488_11D2_81F1_0000B45BAE88__INCLUDED_)
